@@ -57,10 +57,19 @@
 #include <time.h>
 #include <string.h>
 
+#ifdef UPNP_ENABLE_OPEN_SSL
+#include <openssl/ssl.h>
+#endif
+
 #ifndef MSG_NOSIGNAL
 #define MSG_NOSIGNAL 0
 #endif
 
+#ifdef UPNP_ENABLE_OPEN_SSL
+/* OpenSSL context defined in upnpapi.c */
+extern SSL_CTX *gSslCtx;
+#endif
+
 int sock_init(SOCKINFO *info, SOCKET sockfd)
 {
 	assert(info);
@@ -87,12 +96,38 @@ int sock_init_with_ip(SOCKINFO *info, SOCKET sockfd,
 	return UPNP_E_SUCCESS;
 }
 
+#ifdef UPNP_ENABLE_OPEN_SSL
+int sock_ssl_connect(SOCKINFO *info)
+{
+	int status = 0;
+	info->ssl = SSL_new(gSslCtx);
+	if (!info->ssl) {
+		return UPNP_E_SOCKET_ERROR;
+	}
+	status = SSL_set_fd(info->ssl, info->socket);
+	if (status == 1) {
+		status = SSL_connect(info->ssl);
+	}
+	if (status == 1) {
+		return UPNP_E_SUCCESS;
+	}
+	return UPNP_E_SOCKET_ERROR;
+}
+#endif
+
 int sock_destroy(SOCKINFO *info, int ShutdownMethod)
 {
 	int ret = UPNP_E_SUCCESS;
 	char errorBuffer[ERROR_BUFFER_LEN];
 
 	if (info->socket != INVALID_SOCKET) {
+#ifdef UPNP_ENABLE_OPEN_SSL
+		if (info->ssl) {
+			SSL_shutdown(info->ssl);
+			SSL_free(info->ssl);
+			info->ssl = NULL;
+		}
+#endif
 		if (shutdown(info->socket, ShutdownMethod) == -1) {
 			strerror_r(errno, errorBuffer, ERROR_BUFFER_LEN);
 			UpnpPrintf(UPNP_INFO, HTTP, __FILE__, __LINE__,
@@ -139,8 +174,6 @@ static int sock_read_write(
 	size_t byte_left = (size_t)0;
 	ssize_t num_written;
 
-	if (*timeoutSecs < 0)
-		return UPNP_E_TIMEDOUT;
 	FD_ZERO(&readSet);
 	FD_ZERO(&writeSet);
 	if (bRead)
@@ -149,8 +182,8 @@ static int sock_read_write(
 		FD_SET(sockfd, &writeSet);
 	timeout.tv_sec = *timeoutSecs;
 	timeout.tv_usec = 0;
-	while (TRUE) {
-		if (*timeoutSecs == 0)
+	while (1) {
+		if (*timeoutSecs < 0)
 			retCode = select(sockfd + 1, &readSet, &writeSet,
 				NULL, NULL);
 		else
@@ -175,16 +208,36 @@ static int sock_read_write(
 		setsockopt(sockfd, SOL_SOCKET, SO_NOSIGPIPE, &set, sizeof(set));
 #endif
 		if (bRead) {
+#ifdef UPNP_ENABLE_OPEN_SSL
+            if (info->ssl) {
+                numBytes = (long)SSL_read(info->ssl,
+                                          buffer, (size_t)bufsize);
+            }
+            else {
+#endif
 			/* read data. */
 			numBytes = (long)recv(sockfd, buffer, bufsize, MSG_NOSIGNAL);
+#ifdef UPNP_ENABLE_OPEN_SSL
+            }
+#endif
 		} else {
 			byte_left = bufsize;
 			bytes_sent = 0;
 			while (byte_left != (size_t)0) {
+#ifdef UPNP_ENABLE_OPEN_SSL
+                if (info->ssl) {
+                    num_written = SSL_write(info->ssl,
+                                            buffer + bytes_sent, byte_left);
+                }
+                else {
+#endif
 				/* write data. */
 				num_written = send(sockfd,
 					buffer + bytes_sent, byte_left,
 					MSG_DONTROUTE | MSG_NOSIGNAL);
+#ifdef UPNP_ENABLE_OPEN_SSL
+                }
+#endif
 				if (num_written == -1) {
 #ifdef SO_NOSIGPIPE
 					setsockopt(sockfd, SOL_SOCKET,
@@ -212,18 +265,18 @@ static int sock_read_write(
 
 int sock_read(SOCKINFO *info, char *buffer, size_t bufsize, int *timeoutSecs)
 {
-	return sock_read_write(info, buffer, bufsize, timeoutSecs, TRUE);
+	return sock_read_write(info, buffer, bufsize, timeoutSecs, 1);
 }
 
 int sock_write(SOCKINFO *info, const char *buffer, size_t bufsize, int *timeoutSecs)
 {
 	/* Consciently removing constness. */
-	return sock_read_write(info, (char *)buffer, bufsize, timeoutSecs, FALSE);
+	return sock_read_write(info, (char *)buffer, bufsize, timeoutSecs, 0);
 }
 
 int sock_make_blocking(SOCKET sock)
 {
-#ifdef WIN32
+#ifdef _WIN32
 	u_long val = 0;
 	return ioctlsocket(sock, FIONBIO, &val);
 #else
@@ -240,17 +293,17 @@ int sock_make_blocking(SOCKET sock)
 
 int sock_make_no_blocking(SOCKET sock)
 {
-#ifdef WIN32
+#ifdef _WIN32
 	u_long val = 1;
 	return ioctlsocket(sock, FIONBIO, &val);
-#else /* WIN32 */
+#else /* _WIN32 */
 	int val;
 
 	val = fcntl(sock, F_GETFL, 0);
 	if (fcntl(sock, F_SETFL, val | O_NONBLOCK) == -1) {
 		return -1;
 	}
-#endif /* WIN32 */
+#endif /* _WIN32 */
 	return 0;
 }
 
